"""
Tests of the Epoch class
"""

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from neo.core.epoch import Epoch

class TestEpoch(unittest.TestCase):
    pass


if __name__ == "__main__":
    unittest.main()
